Coverage for src/m6rclib/__init__.py: 100%

1"""An embedded compiler for the Metaphor language."""

2

3 __version__ = "0.4.1"

4

5# Export main classes so users can import directly from m6rclib

6 from .metaphor_ast_node import MetaphorASTNode, MetaphorASTNodeType

7 from .metaphor_parser import MetaphorParser, MetaphorParserError, MetaphorParserSyntaxError

8 from .metaphor_formatters import format_ast, format_errors

9

10# List what should be available when using `from m6rclib import *`

11 __all__ = [

12 "MetaphorASTNode",

13 "MetaphorASTNodeType",

14 "MetaphorParser",

15 "MetaphorParserError",

16 "MetaphorParserSyntaxError",

17 "format_ast",

18 "format_errors"

19]